@@ -3,7 +3,7 @@ package POE::Component::WWW::Pastebin::Bot::Pastebot::Create;
 use warnings;
 use strict;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Carp;
 use POE;
@@ -58,6 +58,12 @@ sub _process_request {
     }
 }
 
+1;
+
+__END__
+
+=encoding utf8
+
 =head1 NAME
 
 POE::Component::WWW::Pastebin::Bot::Pastebot::Create - non-blocking POE wrapper around WWW::Pastebin::Bot::Pastebot::Create
